searchNodes=[{"doc":"Defines a whole value pattern container for masses, and utility methods for working with them to improve handling within your applications.","ref":"Massex.html","title":"Massex","type":"module"},{"doc":"Returns a Massex with the arithmetical absolute of the amount","ref":"Massex.html#abs/1","title":"Massex.abs/1","type":"function"},{"doc":"Adds two Massex structs together, returning a MassexExamplesiex&gt; left = Massex.new(10, :gram) iex&gt; right = Massex.new(20, :gram) iex&gt; Massex.add(left, right) %Massex{unit: :gram, amount: Decimal.new(30)}","ref":"Massex.html#add/2","title":"Massex.add/2","type":"function"},{"doc":"Compares two Massex structs, returning 0 on equality, 1 if left is greater than right, or -1 if left is less than rightExamplesiex&gt; less = Massex.new(10, :gram) iex&gt; more = Massex.new(20, :gram) iex&gt; Massex.compare(less, less) 0 iex&gt; Massex.compare(less, more) -1 iex&gt; Massex.compare(more, less) 1","ref":"Massex.html#compare/2","title":"Massex.compare/2","type":"function"},{"doc":"Divides a Massex by the provided denominatorExamplesiex&gt; base = Massex.new(10, :gram) iex&gt; Massex.divide(base, 2) %Massex{amount: Decimal.new(5), unit: :gram}","ref":"Massex.html#divide/2","title":"Massex.divide/2","type":"function"},{"doc":"Returns true if two Massex represent the same amount of massExamplesiex&gt; left = Massex.new(10, :gram) iex&gt; right = Massex.new(10, :gram) iex&gt; Massex.equals?(left, right) true","ref":"Massex.html#equals?/2","title":"Massex.equals?/2","type":"function"},{"doc":"Multiplies a Massex by the provided amountExamplesiex&gt; mass = Massex.new(10, :gram) iex&gt; Massex.multiply(mass, 10) %Massex{amount: Decimal.new(100), unit: :gram}","ref":"Massex.html#multiply/2","title":"Massex.multiply/2","type":"function"},{"doc":"Returns true if the amount of a Massex is less than zeroExamplesiex&gt; Massex.negative?(Massex.new(-10, :gram)) true iex&gt; Massex.negative?(Massex.new(10, :gram)) false","ref":"Massex.html#negative?/1","title":"Massex.negative?/1","type":"function"},{"doc":"Builds a Massex struct from an amount and unitExamplesiex&gt; Massex.new(10, :gram) %Massex{amount: Decimal.new(10), unit: :gram}","ref":"Massex.html#new/2","title":"Massex.new/2","type":"function"},{"doc":"Returns true if the amount of a Massex is more than zeroExamplesiex&gt; Massex.positive?(Massex.new(-10, :gram)) false iex&gt; Massex.positive?(Massex.new(10, :gram)) true","ref":"Massex.html#positive?/1","title":"Massex.positive?/1","type":"function"},{"doc":"Subtracts one Massex struct from another, returning a MassexExamplesiex&gt; left = Massex.new(20, :gram) iex&gt; right = Massex.new(10, :gram) iex&gt; Massex.subtract(left, right) %Massex{unit: :gram, amount: Decimal.new(10)} iex&gt; Massex.subtract(left, 10) %Massex{unit: :gram, amount: Decimal.new(10)}","ref":"Massex.html#subtract/2","title":"Massex.subtract/2","type":"function"},{"doc":"Returns the Decimal amount backing the MassexExamplesiex&gt; mass = Massex.new(20, :gram) iex&gt; Massex.to_decimal(mass) Decimal.new(20)","ref":"Massex.html#to_decimal/1","title":"Massex.to_decimal/1","type":"function"},{"doc":"Returns true if the amount of a Massex is zeroExamplesiex&gt; Massex.zero?(Massex.new(-10, :gram)) false iex&gt; Massex.zero?(Massex.new(0, :gram)) true","ref":"Massex.html#zero?/1","title":"Massex.zero?/1","type":"function"},{"doc":"","ref":"Massex.html#t:t/0","title":"Massex.t/0","type":"type"},{"doc":"Ready-baked utility types to integrate Massex with your Absinthe schemaUsagedefmodule MySchema do # setup import_types Massex.Absinthe.Type end object :lorry do field :mass, :mass end payload field :set_lorry_mass do input do field :id, non_null(:id) field :mass, non_null(:mass_input) end end query { lorry { mass { amount unit } } }","ref":"Massex.Absinthe.Type.html","title":"Massex.Absinthe.Type","type":"module"},{"doc":"Provides a type for Ecto to store masses with their units. The underlying type should be a map, JSONB would be perfect in a PostgreSQL database.Migration Examplecreate table(:foo) do add :mass, :jsonb endSchema Exampleschema &quot;foo&quot; do field :mass, Massex.Ecto.Type end","ref":"Massex.Ecto.Type.html","title":"Massex.Ecto.Type","type":"module"},{"doc":"Callback implementation for Ecto.Type.cast/1.","ref":"Massex.Ecto.Type.html#cast/1","title":"Massex.Ecto.Type.cast/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.dump/1.","ref":"Massex.Ecto.Type.html#dump/1","title":"Massex.Ecto.Type.dump/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1.","ref":"Massex.Ecto.Type.html#embed_as/1","title":"Massex.Ecto.Type.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2.","ref":"Massex.Ecto.Type.html#equal?/2","title":"Massex.Ecto.Type.equal?/2","type":"function"},{"doc":"Callback implementation for Ecto.Type.load/1.","ref":"Massex.Ecto.Type.html#load/1","title":"Massex.Ecto.Type.load/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.type/0.","ref":"Massex.Ecto.Type.html#type/0","title":"Massex.Ecto.Type.type/0","type":"function"},{"doc":"MassexMassex is a simple pattern for holding masses and interacting with them in a sensible manner. It follows the whole value pattern, and allows easy storage, retrieval and mathematics upon values of mass in disparate scales.iex&gt; one = Massex.new(10, :gram) ...&gt; two = Massex.new(10, :ounce) ...&gt; Massex.add(one, two)","ref":"readme.html","title":"Massex","type":"extras"},{"doc":"Massex ships with Jason support which will automatically be loaded if your project is using Jason for JSON handling. Additionally, it also supports Absinthe and Ecto.AbsintheTo activate the Absinthe support, just import the types in your schema:import_types Massex.Absinthe.TypeYou can then use Massex objects in your Schemasobject :lorry do field :mass, :mass endOr in your mutationspayload field :set_lorry_mass do input do field :id, non_null(:id) field :mass, non_null(:mass_input) end endEctoYou can transparently store Massex structs in your schemas by adding the mass field as a map/json/jsonb type in your schema.schema &quot;lorries&quot; do field :mass, Massex.Ecto.Type end","ref":"readme.html#supporting-libraries","title":"Massex - Supporting Libraries","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding massex to your list of dependencies in mix.exs:def deps do [ {:massex, &quot;~&gt; 0.1.0&quot;} ] endDocumentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/massex.","ref":"readme.html#installation","title":"Massex - Installation","type":"extras"},{"doc":"Contribution Guidelines","ref":"contributing.html","title":"Contribution Guidelines","type":"extras"},{"doc":"Fork the repoMake sure everything is working: mix testCreate your feature branch (git checkout -b my-new-feature)Make your changesTest your changesCommit your changes (git commit -am 'Add some feature')If needed please squash commits.Push to the branch (git push origin my-new-feature)Create a Pull Request","ref":"contributing.html#steps","title":"Contribution Guidelines - Steps","type":"extras"}]